summaryrefslogtreecommitdiff
path: root/src/object_cmd.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'src/object_cmd.cpp')
-rw-r--r--src/object_cmd.cpp7
1 files changed, 4 insertions, 3 deletions
diff --git a/src/object_cmd.cpp b/src/object_cmd.cpp
index d07385214..e613c7705 100644
--- a/src/object_cmd.cpp
+++ b/src/object_cmd.cpp
@@ -241,9 +241,10 @@ CommandCost CmdBuildObject(TileIndex tile, DoCommandFlag flags, uint32 p1, uint3
if (callback == CALLBACK_FAILED) {
cost.AddCost(CheckBuildableTile(t, 0, allowed_z, false, false));
- } else if (callback != 0) {
- /* The meaning of bit 10 is inverted in the result of this callback. */
- return GetErrorMessageFromLocationCallbackResult(ToggleBit(callback, 10), spec->grf_prop.grffile->grfid, STR_ERROR_LAND_SLOPED_IN_WRONG_DIRECTION);
+ } else {
+ /* The meaning of bit 10 is inverted for a grf version < 8. */
+ if (spec->grf_prop.grffile->grf_version < 8) ToggleBit(callback, 10);
+ return GetErrorMessageFromLocationCallbackResult(callback, spec->grf_prop.grffile->grfid, STR_ERROR_LAND_SLOPED_IN_WRONG_DIRECTION);
}
}